@@ -1,10 +1,10 @@
 /* vector/gsl_vector_complex_float.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GSL_VECTOR_COMPLEX_FLOAT_H__
@@ -24,6 +24,7 @@
 #include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_complex.h>
+#include <gsl/gsl_check_range.h>
 #include <gsl/gsl_vector_float.h>
 #include <gsl/gsl_vector_complex.h>
 #include <gsl/gsl_block_complex_float.h>
@@ -141,32 +142,20 @@ gsl_vector_complex_float_const_imag (const gsl_vector_complex_float *v);
 
 /* Operations */
 
-gsl_complex_float 
-gsl_vector_complex_float_get (const gsl_vector_complex_float * v, const size_t i);
-
-void gsl_vector_complex_float_set (gsl_vector_complex_float * v, const size_t i,
-                                   gsl_complex_float z);
-
-gsl_complex_float 
-*gsl_vector_complex_float_ptr (gsl_vector_complex_float * v, const size_t i);
-
-const gsl_complex_float 
-*gsl_vector_complex_float_const_ptr (const gsl_vector_complex_float * v, const size_t i);
-
 void gsl_vector_complex_float_set_zero (gsl_vector_complex_float * v);
 void gsl_vector_complex_float_set_all (gsl_vector_complex_float * v,
                                        gsl_complex_float z);
 int gsl_vector_complex_float_set_basis (gsl_vector_complex_float * v, size_t i);
 
 int gsl_vector_complex_float_fread (FILE * stream,
-				    gsl_vector_complex_float * v);
+                                    gsl_vector_complex_float * v);
 int gsl_vector_complex_float_fwrite (FILE * stream,
-				     const gsl_vector_complex_float * v);
+                                     const gsl_vector_complex_float * v);
 int gsl_vector_complex_float_fscanf (FILE * stream,
-				     gsl_vector_complex_float * v);
+                                     gsl_vector_complex_float * v);
 int gsl_vector_complex_float_fprintf (FILE * stream,
-				      const gsl_vector_complex_float * v,
-				      const char *format);
+                                      const gsl_vector_complex_float * v,
+                                      const char *format);
 
 int gsl_vector_complex_float_memcpy (gsl_vector_complex_float * dest, const gsl_vector_complex_float * src);
 
@@ -175,34 +164,50 @@ int gsl_vector_complex_float_reverse (gsl_vector_complex_float * v);
 int gsl_vector_complex_float_swap (gsl_vector_complex_float * v, gsl_vector_complex_float * w);
 int gsl_vector_complex_float_swap_elements (gsl_vector_complex_float * v, const size_t i, const size_t j);
 
-int gsl_vector_complex_float_isnull (const gsl_vector_complex_float * v);
+int gsl_vector_complex_float_equal (const gsl_vector_complex_float * u, 
+                                    const gsl_vector_complex_float * v);
 
-GSL_VAR int gsl_check_range;
+int gsl_vector_complex_float_isnull (const gsl_vector_complex_float * v);
+int gsl_vector_complex_float_ispos (const gsl_vector_complex_float * v);
+int gsl_vector_complex_float_isneg (const gsl_vector_complex_float * v);
+int gsl_vector_complex_float_isnonneg (const gsl_vector_complex_float * v);
+
+int gsl_vector_complex_float_add (gsl_vector_complex_float * a, const gsl_vector_complex_float * b);
+int gsl_vector_complex_float_sub (gsl_vector_complex_float * a, const gsl_vector_complex_float * b);
+int gsl_vector_complex_float_mul (gsl_vector_complex_float * a, const gsl_vector_complex_float * b);
+int gsl_vector_complex_float_div (gsl_vector_complex_float * a, const gsl_vector_complex_float * b);
+int gsl_vector_complex_float_scale (gsl_vector_complex_float * a, const gsl_complex_float x);
+int gsl_vector_complex_float_add_constant (gsl_vector_complex_float * a, const gsl_complex_float x);
+
+INLINE_DECL gsl_complex_float gsl_vector_complex_float_get (const gsl_vector_complex_float * v, const size_t i);
+INLINE_DECL void gsl_vector_complex_float_set (gsl_vector_complex_float * v, const size_t i, gsl_complex_float z);
+INLINE_DECL gsl_complex_float *gsl_vector_complex_float_ptr (gsl_vector_complex_float * v, const size_t i);
+INLINE_DECL const gsl_complex_float *gsl_vector_complex_float_const_ptr (const gsl_vector_complex_float * v, const size_t i);
 
 #ifdef HAVE_INLINE
 
-extern inline
+INLINE_FUN
 gsl_complex_float
 gsl_vector_complex_float_get (const gsl_vector_complex_float * v,
-			      const size_t i)
+                              const size_t i)
 {
-#ifndef GSL_RANGE_CHECK_OFF
-  if (i >= v->size)
+#if GSL_RANGE_CHECK
+  if (GSL_RANGE_COND(i >= v->size))
     {
-      const gsl_complex_float zero = {{0, 0}};
+      gsl_complex_float zero = {{0, 0}};
       GSL_ERROR_VAL ("index out of range", GSL_EINVAL, zero);
     }
 #endif
   return *GSL_COMPLEX_FLOAT_AT (v, i);
 }
 
-extern inline
+INLINE_FUN
 void
 gsl_vector_complex_float_set (gsl_vector_complex_float * v,
-			      const size_t i, gsl_complex_float z)
+                              const size_t i, gsl_complex_float z)
 {
-#ifndef GSL_RANGE_CHECK_OFF
-  if (i >= v->size)
+#if GSL_RANGE_CHECK
+  if (GSL_RANGE_COND(i >= v->size))
     {
       GSL_ERROR_VOID ("index out of range", GSL_EINVAL);
     }
@@ -210,13 +215,13 @@ gsl_vector_complex_float_set (gsl_vector_complex_float * v,
   *GSL_COMPLEX_FLOAT_AT (v, i) = z;
 }
 
-extern inline
+INLINE_FUN
 gsl_complex_float *
 gsl_vector_complex_float_ptr (gsl_vector_complex_float * v,
-			      const size_t i)
+                              const size_t i)
 {
-#ifndef GSL_RANGE_CHECK_OFF
-  if (i >= v->size)
+#if GSL_RANGE_CHECK
+  if (GSL_RANGE_COND(i >= v->size))
     {
       GSL_ERROR_NULL ("index out of range", GSL_EINVAL);
     }
@@ -224,13 +229,13 @@ gsl_vector_complex_float_ptr (gsl_vector_complex_float * v,
   return GSL_COMPLEX_FLOAT_AT (v, i);
 }
 
-extern inline
+INLINE_FUN
 const gsl_complex_float *
 gsl_vector_complex_float_const_ptr (const gsl_vector_complex_float * v,
                                     const size_t i)
 {
-#ifndef GSL_RANGE_CHECK_OFF
-  if (i >= v->size)
+#if GSL_RANGE_CHECK
+  if (GSL_RANGE_COND(i >= v->size))
     {
       GSL_ERROR_NULL ("index out of range", GSL_EINVAL);
     }
